@@ -15,6 +15,7 @@ from PIL import Image
 import numpy as np
 import os
 import matplotlib.pyplot as plt
+import time
 
 class Trainer():
     def __init__(self, config, pretrained=True):
@@ -47,33 +48,35 @@ class Trainer():
 
         self.optimizer = ScheduledOptim(
             Adam(self.model.parameters(), betas=(0.9, 0.98), eps=1e-09),
-            0.2, config['transformer']['d_model'], config['optimizer']['n_warmup_steps'])
+            config['optimizer']['init_lr'], config['transformer']['d_model'], config['optimizer']['n_warmup_steps'])
 
 #        self.criterion = nn.CrossEntropyLoss(ignore_index=0) 
         self.criterion = LabelSmoothingLoss(len(self.vocab), padding_idx=self.vocab.pad, smoothing=0.1)
 
-        self.train_gen = DataGen(self.data_root, self.train_annotation, self.vocab, self.device)
+        self.train_gen = DataGen(self.data_root, self.train_annotation, self.vocab, self.device, **config['dataloader'])
         if self.valid_annotation:
-            self.valid_gen = DataGen(self.data_root, self.valid_annotation, self.vocab, self.device)
+            self.valid_gen = DataGen(self.data_root, self.valid_annotation, self.vocab, self.device, **config['dataloader'])
         
         self.train_losses = []
-
+        
     def train(self):
         total_loss = 0
-       
         for epoch in range(self.num_epochs):
             self.epoch = epoch
-            for batch in self.train_gen.gen(self.batch_size, last_batch=False):
+            data_iter = self.train_gen.gen(self.batch_size, last_batch=False)
+
+            for batch in data_iter:
                 self.iter += 1
 
                 loss = self.step(batch)
-                
+
                 total_loss += loss
                 self.train_losses.append((self.iter, loss))
 
                 if self.iter % self.print_every == self.print_every - 1:
-                    info = 'iter: {:06d} - epoch: {:03d} - train loss: {:.4f}'.format(self.iter, epoch, total_loss/self.print_every)
+                    info = 'iter: {:06d} - epoch: {:03d} - train loss: {:.4f} - lr: {:.4e}'.format(self.iter, epoch, total_loss/self.print_every, self.optimizer.lr)
                     total_loss = 0
+
                     print(info) 
                     self.logger.log(info)
 
